PyACI: Python Bindings for Cisco ACI REST API
=============================================

.. image:: https://api.codacy.com/project/badge/Grade/3f99112bec114ef88a7c61090606cffb
   :alt: Codacy Badge
   :target: https://app.codacy.com/app/kprav33n/pyaci?utm_source=github.com&utm_medium=referral&utm_content=datacenter/pyaci&utm_campaign=badger

.. image:: https://circleci.com/gh/datacenter/pyaci.svg?style=shield&circle-token=:circle-token
   :alt: circleci status
   :target: https://circleci.com/gh/datacenter/pyaci

.. image:: https://travis-ci.org/datacenter/pyaci.svg?branch=master
   :alt: Travis CI status
   :target: https://travis-ci.org/datacenter/pyaci

.. image:: https://codecov.io/gh/datacenter/pyaci/branch/master/graph/badge.svg
   :alt: codecov status
   :target: https://codecov.io/gh/datacenter/pyaci

.. image:: https://readthedocs.org/projects/pyaci/badge/?version=latest&style=plastic
   :alt: Doc Status
   :target: http://pyaci.readthedocs.io/en/latest/

Documentation
-------------

Documentation is available at http://pyaci.readthedocs.io/en/latest/

Examples
--------

Jupyter Notebook based examples can be found in `examples <examples>`_ directory.
